@@ -76,11 +76,11 @@ def wait_for_object(build_object):
     state_items = [
         {
             "state": "queued",
-            "message": click.style("🤔 Queued: ", fg="white", bold=True),
+            "message": click.style("⏳ Queued: ", fg="white", bold=True),
         },
         {
             "state": "building",
-            "message": click.style("🚀 Building: ", fg="cyan", bold=True),
+            "message": click.style("⚗️  Building: ", fg="cyan", bold=True),
         },
     ]
     if not wait_for_state_change(build_object, state_items):
